@@ -16,7 +16,8 @@ DASK_SCATTER_TIMEOUT = 120
 
 
 def amusr_regress_dask(X, Y, priors, prior_weight, n_tasks, genes, tfs, G, remove_autoregulation=True,
-                       lambda_Bs=None, lambda_Ss=None, Cs=None, Ss=None, regression_function=None):
+                       lambda_Bs=None, lambda_Ss=None, Cs=None, Ss=None, regression_function=None, 
+                       tol=None, rel_tol=None):
     """
     Execute multitask (AMUSR)
 
@@ -54,7 +55,7 @@ def amusr_regress_dask(X, Y, priors, prior_weight, n_tasks, genes, tfs, G, remov
 
         prior = format_prior(prior, gene, tasks, prior_weight, tfs=tf)
         return j, regression_function(x, y, tf, tasks, gene, prior,
-                                      lambda_Bs=lambda_Bs, lambda_Ss=lambda_Ss, Cs=Cs, Ss=Ss)
+                                      lambda_Bs=lambda_Bs, lambda_Ss=lambda_Ss, Cs=Cs, Ss=Ss, tol=tol, rel_tol=rel_tol)
 
     def response_maker(y_df, i):
         y = []
@@ -81,6 +82,7 @@ def amusr_regress_dask(X, Y, priors, prior_weight, n_tasks, genes, tfs, G, remov
 
     DaskController.client.cancel(scatter_x)
     DaskController.client.cancel(scatter_priors)
+    DaskController.client.restart()
 
     return result_list
 
