@@ -1,6 +1,6 @@
 from inferelator.utils.validator import Validator, is_string
-from inferelator.utils.debug import Debug, slurm_envs
+from inferelator.utils.debug import Debug, slurm_envs, inferelator_verbose_level
 from inferelator.utils.loader import InferelatorDataLoader, DEFAULT_PANDAS_TSV_SETTINGS
 from inferelator.utils.data import (InferelatorData, df_from_tsv, array_set_diag, df_set_diag,
-                                    melt_and_reindex_dataframe, make_array_2d, scale_vector, dot_product)
+                                    melt_and_reindex_dataframe, make_array_2d, scale_vector, DotProduct )
 
